Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(511)

Unified Diff: ash/wm/tablet_mode/tablet_mode_window_state.h

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/wm/tablet_mode/tablet_mode_window_state.h
diff --git a/ash/wm/maximize_mode/maximize_mode_window_state.h b/ash/wm/tablet_mode/tablet_mode_window_state.h
similarity index 80%
rename from ash/wm/maximize_mode/maximize_mode_window_state.h
rename to ash/wm/tablet_mode/tablet_mode_window_state.h
index 4ab3d5a2712149ba11213ba2c69f1a9c0c6cc658..7c4c630fdc2e76f7b830792f8cd9078398365787 100644
--- a/ash/wm/maximize_mode/maximize_mode_window_state.h
+++ b/ash/wm/tablet_mode/tablet_mode_window_state.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef ASH_WM_MAXIMIZE_MODE_MAXIMIZE_MODE_WINDOW_STATE_H_
-#define ASH_WM_MAXIMIZE_MODE_MAXIMIZE_MODE_WINDOW_STATE_H_
+#ifndef ASH_WM_TABLET_MODE_TABLET_MODE_WINDOW_STATE_H_
+#define ASH_WM_TABLET_MODE_TABLET_MODE_WINDOW_STATE_H_
#include <memory>
@@ -11,13 +11,13 @@
#include "base/macros.h"
namespace ash {
-class MaximizeModeWindowManager;
+class TabletModeWindowManager;
-// The MaximizeModeWindowState implementation which reduces all possible window
+// The TabletModeWindowState implementation which reduces all possible window
// states to minimized and maximized. If a window cannot be maximized it will be
// set to normal. If a window cannot fill the entire workspace it will be
// centered within the workspace.
-class MaximizeModeWindowState : public wm::WindowState::State {
+class TabletModeWindowState : public wm::WindowState::State {
public:
// Called when the window position might need to be updated.
static void UpdateWindowPosition(wm::WindowState* window_state);
@@ -26,14 +26,13 @@ class MaximizeModeWindowState : public wm::WindowState::State {
// state handler. Upon destruction it will restore the previous state handler
// and call |creator::WindowStateDestroyed()| to inform that the window mode
// was reverted to the old window manager.
- MaximizeModeWindowState(aura::Window* window,
- MaximizeModeWindowManager* creator);
- ~MaximizeModeWindowState() override;
+ TabletModeWindowState(aura::Window* window, TabletModeWindowManager* creator);
+ ~TabletModeWindowState() override;
void set_ignore_wm_events(bool ignore) { ignore_wm_events_ = ignore; }
- // Leaves the maximize mode by reverting to previous state object.
- void LeaveMaximizeMode(wm::WindowState* window_state);
+ // Leaves the tablet mode by reverting to previous state object.
+ void LeaveTabletMode(wm::WindowState* window_state);
// Sets whether to ignore bounds updates. If set to false, immediately does a
// bounds update as the current window bounds may no longer be correct.
@@ -73,7 +72,7 @@ class MaximizeModeWindowState : public wm::WindowState::State {
aura::Window* window_;
// The creator which needs to be informed when this state goes away.
- MaximizeModeWindowManager* creator_;
+ TabletModeWindowManager* creator_;
// The current state type. Due to the nature of this state, this can only be
// WM_STATE_TYPE{NORMAL, MINIMIZED, MAXIMIZED}.
@@ -85,9 +84,9 @@ class MaximizeModeWindowState : public wm::WindowState::State {
// If true, the state will not process events.
bool ignore_wm_events_ = false;
- DISALLOW_COPY_AND_ASSIGN(MaximizeModeWindowState);
+ DISALLOW_COPY_AND_ASSIGN(TabletModeWindowState);
};
} // namespace ash
-#endif // ASH_WM_MAXIMIZE_MODE_MAXIMIZE_MODE_WINDOW_STATE_H_
+#endif // ASH_WM_TABLET_MODE_TABLET_MODE_WINDOW_STATE_H_

Powered by Google App Engine
This is Rietveld 408576698